/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@ricochet.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001-2004 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.jsp;

import java.io.IOException;
import java.net.URLEncoder;
import javax.servlet.jsp.*;
import javax.servlet.jsp.tagext.*;
import com.silverwrist.util.StringUtil;
import com.silverwrist.venice.ui.*;
import com.silverwrist.venice.ui.helpers.HTMLRendering;

public class UtilLinkTag extends VeniceTagSupport
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static final String LOCATION_PARAM = "${location}";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String m_href = null;
  private String m_type = null;
  private String m_class = null;
  private String m_target = null;
  private String m_title = null;

  /*--------------------------------------------------------------------------------
   * Overrides from class TagSupport
   *--------------------------------------------------------------------------------
   */

  public int doStartTag() throws JspException
  {
    // Check the parameters!
    if (m_href==null)
      throw new JspTagException("<util:link/> href not specified!");
    if (m_type==null)
      throw new JspTagException("<util:link/> type not specified!");

    RequestInput ri = getRequestInput();
    HTMLRendering html = (HTMLRendering)(ri.queryService(HTMLRendering.class));

    int ityp = html.convertLinkType(m_type);
    if (ityp==-1)
      throw new JspTagException("<util:link/> invalid link type!");

    try
    { // Do parameter replacement on the HREF string if necessary.
      if (m_href.indexOf(LOCATION_PARAM)>=0)
	m_href = StringUtil.replaceAllInstances(m_href,LOCATION_PARAM,URLEncoder.encode(ri.getLocation(),"UTF-8"));

      // write out what we came here to accomplish
      JspWriter out = pageContext.getOut();
      out.write("<a ");
      if (m_class!=null)
	out.write("class=\"" + m_class + "\" ");
      out.write("href=\"" + html.formatURL(m_href,ityp) + "\"");
      if (m_title!=null)
	out.write(" title=\"" + m_title + "\"");
      if (m_target!=null)
	out.write(" target=\"" + m_target + "\"");
      out.write(">");

    } // end try
    catch (IOException e)
    { // convert the I/O error into something the servlet engine can deal with
      throw new JspTagException("error writing <a> tag - " + e.getMessage());

    } // end catch

    return EVAL_BODY_INCLUDE;

  } // end doStartTag

  public int doEndTag() throws JspException
  {
    try
    { // write out what we came here to accomplish
      JspWriter out = pageContext.getOut();
      out.write("</a>");

    } // end try
    catch (IOException e)
    { // convert the I/O error into something the servlet engine can deal with
      throw new JspTagException("error writing </a> tag - " + e.getMessage());

    } // end catch

    return EVAL_PAGE;

  } // end doEndTag

  public void release()
  {
    super.release();
    m_href = null;
    m_type = null;
    m_class = null;
    m_target = null;
    m_title = null;

  } // end release

  /*--------------------------------------------------------------------------------
   * Attribute set functions
   *--------------------------------------------------------------------------------
   */

  public void setHref(String s)
  {
    m_href = s;

  } // end setHref

  public void setType(String s)
  {
    m_type = s;

  } // end setType

  public void setAclass(String s)
  {
    m_class = s;

  } // end setAclass

  public void setTarget(String s)
  {
    m_target = s;

  } // end setTarget

  public void setTitle(String s)
  {
    m_title = s;

  } // end setTitle

} // end class UtilLinkTag
