/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@ricochet.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001-2004 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.view;

import java.io.IOException;
import java.util.*;
import com.silverwrist.util.StringUtil;
import com.silverwrist.venice.ui.*;
import com.silverwrist.venice.ui.helpers.ResourceLoader;
import com.silverwrist.venice.ui.menus.MenuComponent;
import com.silverwrist.venice.ui.menus.MenuTemplate;

public class MenuView implements ContentDirect
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private int m_menu_selector = MENU_SELECTOR_NOCHANGE;
  private String m_qid = null;
  private MenuComponent m_component;
  private Set m_defines = Collections.EMPTY_SET;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public MenuView(MenuComponent component)
  {
    m_component = component;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Implementations from interface Content
   *--------------------------------------------------------------------------------
   */

  public boolean needFrame()
  {
    return true;

  } // end needFrame

  public int getMenuSelector()
  {
    return m_menu_selector;

  } // end getMenuSelector

  public String getPageTitle(RequestOutput ro)
  {
    return m_component.getTitle(ro);

  } // end getPageTitle

  public String getPageQID()
  {
    return m_qid;

  } // end getPageQID

  /*--------------------------------------------------------------------------------
   * Implementations from interface ContentDirect
   *--------------------------------------------------------------------------------
   */

  public void render(RequestOutput out) throws IOException
  {
    ResourceLoader rload = (ResourceLoader)(out.queryService(ResourceLoader.class));
    MenuTemplate templ = rload.getMenuTemplate("normal");
    m_component.render(out,null,templ,m_defines);

  } // end render

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public final void setMenuSelector(int sel)
  {
    m_menu_selector = sel;

  } // end setMenuSelector

  public final void setPageQID(String s)
  {
    m_qid = s;

  } // end setPageQID

  public final void define(String symbol)
  {
    if (m_defines==Collections.EMPTY_SET)
      m_defines = new HashSet();
    m_defines.add(symbol);

  } // end define

} // end class MenuView
